@@ -7,7 +7,7 @@ test_that("10-dimensional 2-hyp_fam copula", {
   h1 = h1 / 1000
   h2 = h2 = runif(n = 10, min = 1, max = 1000)
   h2 = h1 / 1000
-  cop = copula1(h1 = h1 , h2 = h2 , numSlices = 10, N = 100000)
+  cop = copula(r1 = h1 , r2 = h2 , m = 10, n = 100000)
   res = sum(cop)
   expect_equal(res, 1)
 })
@@ -17,7 +17,7 @@ test_that("20-dimensional 1_hyp_1_ell fam copula", {
   h = h / 1000
   E = replicate(20, rnorm(30))
   E = cov(E)
-  cop = copula2(h = h , E = E , numSlices = 100, N = 100000)
+  cop = copula(r1 = h , sigma = E , m = 100, n = 100000)
   res = sum(cop)
   expect_equal(res, 1)
 })
\ No newline at end of file
